## What developers say

"Thanks for developing this, it seems like a much 'healthier' way to do web development."
- Fran

"Moral of this story is as follows... there is boring (COBOL, J2EEcirca 1999, JDK 1.4, Visual Basic), there is cutting edge (Ajax libs), bleeding edge (GWT), and scarry bleeding ouch ouch ouch I am bloodyedge... Pyjamas is closer to the last extreme."
- Brian

## News

January 2012
  Community contributions to website
July 2010
  Pyjamas-based Mailing list and Git Browser created
15th June 2010
  New website!

## Useful Links

- Manual - a comprehensive guide to Pyjamas, as a Pyjamas-based AJAX book reader.
- Pyjamas Wiki - reference discussions about recurring topics.
- Mailing List Viewer - for browsing through current discussions.
- Legacy Mailing List - archived discussion group list at Google Groups.
- Bug Tracker - see the currently reported issues.
- Sourcecode - Pyjamas Git repository browser.
- GWT Documentation is useful since pyjamas reimplements much of the same GWT Widget API in Python.
- Examples - a page of working applications.
- T-Shirts - show your Pyjamas Pride with these.

## Sites using Pyjamas

- Grafpad Drawing app
- beamMail IMAP web client
- Tickery Twitter analyser
- Nagare Web framework